@@ -940,7 +940,7 @@ clutter_path_get_n_nodes (ClutterPath *path)
  * clutter_path_get_node:
  * @path: a #ClutterPath
  * @index_: the node number to retrieve
- * @node: (out): a location to store a copy of the node
+ * @node: a location to store a copy of the node
  *
  * Retrieves the node of the path indexed by @index.
  *
@@ -1384,7 +1384,7 @@ clutter_path_ensure_node_data (ClutterPath *path)
  * clutter_path_get_position:
  * @path: a #ClutterPath
  * @progress: a position along the path as a fraction of its length
- * @position: (out): location to store the position
+ * @position: location to store the position
  *
  * The value in @progress represents a position along the path where
  * 0.0 is the beginning and 1.0 is the end of the path. An
@@ -1582,3 +1582,65 @@ clutter_path_node_equal (const ClutterPathNode *node_a,
 
   return TRUE;
 }
+
+G_DEFINE_BOXED_TYPE (ClutterKnot, clutter_knot,
+                     clutter_knot_copy,
+                     clutter_knot_free);
+
+/**
+ * clutter_knot_copy:
+ * @knot: a #ClutterKnot
+ *
+ * Makes an allocated copy of a knot.
+ *
+ * Return value: the copied knot.
+ *
+ * Since: 0.2
+ */
+ClutterKnot *
+clutter_knot_copy (const ClutterKnot *knot)
+{
+  if (G_UNLIKELY (knot == NULL))
+    return NULL;
+
+  return g_slice_dup (ClutterKnot, knot);
+}
+
+/**
+ * clutter_knot_free:
+ * @knot: a #ClutterKnot
+ *
+ * Frees the memory of an allocated knot.
+ *
+ * Since: 0.2
+ */
+void
+clutter_knot_free (ClutterKnot *knot)
+{
+  if (G_LIKELY (knot != NULL))
+    g_slice_free (ClutterKnot, knot);
+}
+
+/**
+ * clutter_knot_equal:
+ * @knot_a: First knot
+ * @knot_b: Second knot
+ *
+ * Compares to knot and checks if the point to the same location.
+ *
+ * Return value: %TRUE if the knots point to the same location.
+ *
+ * Since: 0.2
+ */
+gboolean
+clutter_knot_equal (const ClutterKnot *knot_a,
+                    const ClutterKnot *knot_b)
+{
+  g_return_val_if_fail (knot_a != NULL, FALSE);
+  g_return_val_if_fail (knot_b != NULL, FALSE);
+
+  if (knot_a == knot_b)
+    return TRUE;
+
+  return knot_a->x == knot_b->x && knot_a->y == knot_b->y;
+}
