@@ -40,6 +40,7 @@
 #include "clutter-layout-manager.h"
 #include "clutter-master-clock.h"
 #include "clutter-settings.h"
+#include "clutter-stage-manager.h"
 #include "clutter-stage.h"
 
 G_BEGIN_DECLS
@@ -124,12 +125,15 @@ struct _ClutterMainContext
   /* the main windowing system backend */
   ClutterBackend *backend;
 
+  /* the object holding all the stage instances */
+  ClutterStageManager *stage_manager;
+
+  /* the clock driving all the frame operations */
+  ClutterMasterClock *master_clock;
+
   /* the main event queue */
   GQueue *events_queue;
 
-  /* timer used to print the FPS count */
-  GTimer *timer;
-
   ClutterPickMode  pick_mode;
 
   /* mapping between reused integer ids and actors */
@@ -173,6 +177,7 @@ struct _ClutterMainContext
   guint motion_events_per_actor : 1;
   guint defer_display_setup     : 1;
   guint options_parsed          : 1;
+  guint show_fps                : 1;
 };
 
 /* shared between clutter-main.c and clutter-frame-source.c */
@@ -199,6 +204,7 @@ ClutterActor *          _clutter_context_peek_shader_stack              (void);
 guint32                 _clutter_context_acquire_id                     (gpointer      key);
 void                    _clutter_context_release_id                     (guint32       id_);
 gboolean                _clutter_context_get_motion_events_enabled      (void);
+gboolean                _clutter_context_get_show_fps                   (void);
 
 const gchar *_clutter_gettext (const gchar *str);
 
@@ -211,6 +217,8 @@ void            _clutter_id_to_color            (guint         id,
 ClutterActor *  _clutter_get_actor_by_id        (ClutterStage *stage,
                                                  guint32       actor_id);
 
+gboolean        _clutter_get_sync_to_vblank     (void);
+
 /* use this function as the accumulator if you have a signal with
  * a G_TYPE_BOOLEAN return value; this will stop the emission as
  * soon as one handler returns TRUE
@@ -235,6 +243,10 @@ void  _clutter_util_fully_transform_vertices (const CoglMatrix    *modelview,
                                               ClutterVertex       *vertices_out,
                                               int                  n_vertices);
 
+void _clutter_util_rectangle_union (const cairo_rectangle_int_t *src1,
+                                    const cairo_rectangle_int_t *src2,
+                                    cairo_rectangle_int_t       *dest);
+
 typedef struct _ClutterPlane
 {
   CoglVector3 v0;
