@@ -35,8 +35,10 @@ typedef struct _ClutterStageQueueRedrawEntry ClutterStageQueueRedrawEntry;
 
 /* stage */
 ClutterStageWindow *_clutter_stage_get_default_window    (void);
-void                _clutter_stage_do_paint              (ClutterStage          *stage,
-                                                          const ClutterGeometry *clip);
+
+void                _clutter_stage_do_paint              (ClutterStage                *stage,
+                                                          const cairo_rectangle_int_t *clip);
+
 void                _clutter_stage_set_window            (ClutterStage          *stage,
                                                           ClutterStageWindow    *stage_window);
 ClutterStageWindow *_clutter_stage_get_window            (ClutterStage          *stage);
@@ -90,10 +92,6 @@ void            _clutter_stage_remove_device    (ClutterStage       *stage,
 gboolean        _clutter_stage_has_device       (ClutterStage       *stage,
                                                  ClutterInputDevice *device);
 
-void     _clutter_stage_set_motion_events_enabled (ClutterStage *stage,
-                                                   gboolean      enabled);
-gboolean _clutter_stage_get_motion_events_enabled (ClutterStage *stage);
-
 CoglFramebuffer *_clutter_stage_get_active_framebuffer (ClutterStage *stage);
 
 gint32          _clutter_stage_acquire_pick_id          (ClutterStage *stage,
@@ -103,6 +101,14 @@ void            _clutter_stage_release_pick_id          (ClutterStage *stage,
 ClutterActor *  _clutter_stage_get_actor_by_pick_id     (ClutterStage *stage,
                                                          gint32        pick_id);
 
+void            _clutter_stage_add_drag_actor           (ClutterStage       *stage,
+                                                         ClutterInputDevice *device,
+                                                         ClutterActor       *actor);
+ClutterActor *  _clutter_stage_get_drag_actor           (ClutterStage       *stage,
+                                                         ClutterInputDevice *device);
+void            _clutter_stage_remove_drag_actor        (ClutterStage       *stage,
+                                                         ClutterInputDevice *device);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_STAGE_PRIVATE_H__ */
