@@ -79,7 +79,6 @@
 
 #define CLUTTER_DISABLE_DEPRECATION_WARNINGS
 #include "clutter-behaviour.h"
-#include "clutter-alpha.h"
 
 #include "clutter-debug.h"
 #include "clutter-main.h"
@@ -88,6 +87,14 @@
 #include "clutter-scriptable.h"
 #include "clutter-script-private.h"
 
+static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
+
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ClutterBehaviour,
+                                  clutter_behaviour,
+                                  G_TYPE_OBJECT,
+                                  G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
+                                                         clutter_scriptable_iface_init));
+
 struct _ClutterBehaviourPrivate
 {
   ClutterAlpha *alpha;
@@ -114,14 +121,10 @@ enum {
 
 static guint behave_signals[LAST_SIGNAL] = { 0 };
 
-static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
-
-G_DEFINE_ABSTRACT_TYPE_WITH_CODE (ClutterBehaviour,
-                                  clutter_behaviour,
-                                  G_TYPE_OBJECT,
-                                  G_ADD_PRIVATE (ClutterBehaviour)
-                                  G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
-                                                         clutter_scriptable_iface_init))
+#define CLUTTER_BEHAVIOUR_GET_PRIVATE(obj)         \
+              (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
+               CLUTTER_TYPE_BEHAVIOUR,             \
+               ClutterBehaviourPrivate))
 
 static gboolean
 clutter_behaviour_parse_custom_node (ClutterScriptable *scriptable,
@@ -287,12 +290,14 @@ clutter_behaviour_class_init (ClutterBehaviourClass *klass)
 		  _clutter_marshal_VOID__OBJECT,
 		  G_TYPE_NONE, 1,
 		  CLUTTER_TYPE_ACTOR);
+
+  g_type_class_add_private (klass, sizeof (ClutterBehaviourPrivate));
 }
 
 static void
 clutter_behaviour_init (ClutterBehaviour *self)
 {
-  self->priv = clutter_behaviour_get_instance_private (self);
+  self->priv = CLUTTER_BEHAVIOUR_GET_PRIVATE (self);
 }
 
 static void
