@@ -22,7 +22,6 @@
 #include "config.h"
 
 #include <math.h>
-#include <stdlib.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -46,6 +45,10 @@
 #include "clutter-private.h"
 #include "clutter-stage-private.h"
 
+#ifdef HAVE_XFIXES
+#include <X11/extensions/Xfixes.h>
+#endif
+
 #define STAGE_X11_IS_MAPPED(s)  ((((ClutterStageX11 *) (s))->wm_state & STAGE_X11_WITHDRAWN) == 0)
 
 static ClutterStageWindowIface *clutter_stage_window_parent_iface = NULL;
@@ -53,8 +56,6 @@ static ClutterStageWindowIface *clutter_stage_window_parent_iface = NULL;
 static void clutter_stage_window_iface_init     (ClutterStageWindowIface     *iface);
 static void clutter_event_translator_iface_init (ClutterEventTranslatorIface *iface);
 
-static ClutterStageCogl *clutter_x11_get_stage_window_from_window (Window win);
-
 static GHashTable *clutter_stages_by_xid = NULL;
 
 #define clutter_stage_x11_get_type      _clutter_stage_x11_get_type
@@ -148,10 +149,10 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
                                       &min_height);
 
       if (new_width <= 0)
-        new_width = min_width * stage_x11->scale_factor;
+        new_width = min_width;
 
       if (new_height <= 0)
-        new_height = min_height * stage_x11->scale_factor;
+        new_height = min_height;
 
       size_hints->flags = 0;
 
@@ -161,8 +162,8 @@ clutter_stage_x11_fix_window_size (ClutterStageX11 *stage_x11,
         {
           if (resize)
             {
-              size_hints->min_width = min_width * stage_x11->scale_factor;
-              size_hints->min_height = min_height * stage_x11->scale_factor;
+              size_hints->min_width = min_width;
+              size_hints->min_height = min_height;
               size_hints->flags = PMinSize;
             }
           else
@@ -205,15 +206,8 @@ clutter_stage_x11_get_geometry (ClutterStageWindow    *stage_window,
 
   geometry->x = geometry->y = 0;
 
-  /* If we're fullscreen, return the size of the display.
-   *
-   * FIXME - this is utterly broken for anything that is not a single
-   * head set up; the window manager will give us the right size in a
-   * ConfigureNotify, but between the fullscreen signal emission on the
-   * stage and the following frame, the size returned by the stage will
-   * be wrong.
-   */
-  if (_clutter_stage_is_fullscreen (stage_cogl->wrapper) &&
+  /* If we're fullscreen, return the size of the display. */
+  if ((stage_x11->state & CLUTTER_STAGE_STATE_FULLSCREEN) &&
       stage_x11->fullscreening)
     {
       geometry->width = DisplayWidth (backend_x11->xdpy, backend_x11->xscreen_num);
@@ -222,8 +216,8 @@ clutter_stage_x11_get_geometry (ClutterStageWindow    *stage_window,
       return;
     }
 
-  geometry->width = stage_x11->xwin_width / stage_x11->scale_factor;
-  geometry->height = stage_x11->xwin_height / stage_x11->scale_factor;
+  geometry->width = stage_x11->xwin_width;
+  geometry->height = stage_x11->xwin_height;
 }
 
 static void
@@ -241,8 +235,8 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
        * so we need to manually set the size and queue a relayout on the
        * stage here (as is normally done in response to ConfigureNotify).
        */
-      stage_x11->xwin_width = width * stage_x11->scale_factor;
-      stage_x11->xwin_height = height * stage_x11->scale_factor;
+      stage_x11->xwin_width = width;
+      stage_x11->xwin_height = height;
       clutter_actor_queue_relayout (CLUTTER_ACTOR (stage_cogl->wrapper));
       return;
     }
@@ -263,9 +257,6 @@ clutter_stage_x11_resize (ClutterStageWindow *stage_window,
 
   CLUTTER_NOTE (BACKEND, "New size received: (%d, %d)", width, height);
 
-  width *= stage_x11->scale_factor;
-  height *= stage_x11->scale_factor;
-
   if (stage_x11->xwin != None)
     {
       clutter_stage_x11_fix_window_size (stage_x11, width, height);
@@ -362,10 +353,19 @@ set_cursor_visible (ClutterStageX11 *stage_x11)
 
   if (stage_x11->is_cursor_visible)
     {
+#if 0 /* HAVE_XFIXES - seems buggy/unreliable */
+      XFixesShowCursor (backend_x11->xdpy, stage_x11->xwin);
+#else
       XUndefineCursor (backend_x11->xdpy, stage_x11->xwin);
+#endif /* HAVE_XFIXES */
     }
   else
     {
+#if 0 /* HAVE_XFIXES - seems buggy/unreliable, check cursor in firefox 
+       *               loading page after hiding.  
+      */
+      XFixesHideCursor (backend_x11->xdpy, stage_x11->xwin);
+#else
       XColor col;
       Pixmap pix;
       Cursor curs;
@@ -378,6 +378,7 @@ set_cursor_visible (ClutterStageX11 *stage_x11)
                                   1, 1);
       XFreePixmap (backend_x11->xdpy, pix);
       XDefineCursor (backend_x11->xdpy, stage_x11->xwin, curs);
+#endif /* HAVE_XFIXES */
     }
 }
 
@@ -417,6 +418,99 @@ _clutter_stage_x11_update_foreign_event_mask (CoglOnscreen *onscreen,
                            &attrs);
 }
 
+static gboolean
+clutter_stage_x11_realize (ClutterStageWindow *stage_window)
+{
+  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
+  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_window);
+  ClutterBackend *backend = CLUTTER_BACKEND (stage_cogl->backend);
+  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
+  ClutterDeviceManager *device_manager;
+  int event_flags;
+  gfloat width, height;
+
+  clutter_actor_get_size (CLUTTER_ACTOR (stage_cogl->wrapper),
+			  &width, &height);
+
+  stage_cogl->onscreen = cogl_onscreen_new (backend->cogl_context,
+                                            width, height);
+
+  if (stage_x11->xwin != None)
+    {
+      cogl_x11_onscreen_set_foreign_window_xid (stage_cogl->onscreen,
+                                                stage_x11->xwin,
+                                                _clutter_stage_x11_update_foreign_event_mask,
+                                                stage_x11);
+
+    }
+
+  /* Chain to the parent class now. ClutterStageCogl will call cogl_framebuffer_allocate,
+     which will create the X Window we need */
+
+  if (!(clutter_stage_window_parent_iface->realize (stage_window)))
+    return FALSE;
+
+  if (stage_x11->xwin == None)
+    stage_x11->xwin = cogl_x11_onscreen_get_window_xid (stage_cogl->onscreen);
+
+  if (clutter_stages_by_xid == NULL)
+    clutter_stages_by_xid = g_hash_table_new (NULL, NULL);
+
+  g_hash_table_insert (clutter_stages_by_xid,
+                       GINT_TO_POINTER (stage_x11->xwin),
+                       stage_x11);
+
+  set_wm_pid (stage_x11);
+  set_wm_title (stage_x11);
+  set_cursor_visible (stage_x11);
+
+
+  /* the masks for the events we want to select on a stage window;
+   * KeyPressMask and KeyReleaseMask are necessary even with XI1
+   * because key events are broken with that extension, and will
+   * be fixed by XI2
+   */
+  event_flags = CLUTTER_STAGE_X11_EVENT_MASK;
+
+  /* we unconditionally select input events even with event retrieval
+   * disabled because we need to guarantee that the Clutter internal
+   * state is maintained when calling clutter_x11_handle_event() without
+   * requiring applications or embedding toolkits to select events
+   * themselves. if we did that, we'd have to document the events to be
+   * selected, and also update applications and embedding toolkits each
+   * time we added a new mask, or a new class of events.
+   *
+   * see: http://bugzilla.clutter-project.org/show_bug.cgi?id=998
+   * for the rationale of why we did conditional selection. it is now
+   * clear that a compositor should clear out the input region, since
+   * it cannot assume a perfectly clean slate coming from us.
+   *
+   * see: http://bugzilla.clutter-project.org/show_bug.cgi?id=2228
+   * for an example of things that break if we do conditional event
+   * selection.
+   */
+  XSelectInput (backend_x11->xdpy, stage_x11->xwin, event_flags);
+
+  /* input events also depent on the actual device, so we need to
+   * use the device manager to let every device select them, using
+   * the event mask we passed to XSelectInput as the template
+   */
+  device_manager = clutter_device_manager_get_default ();
+  _clutter_device_manager_select_stage_events (device_manager,
+                                               stage_cogl->wrapper,
+                                               event_flags);
+
+  /* no user resize.. */
+  clutter_stage_x11_fix_window_size (stage_x11,
+                                     stage_x11->xwin_width,
+                                     stage_x11->xwin_height);
+  clutter_stage_x11_set_wm_protocols (stage_x11);
+
+  CLUTTER_NOTE (BACKEND, "Successfully realized stage");
+
+  return TRUE;
+}
+
 static void
 clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
                                   gboolean            is_fullscreen)
@@ -430,7 +524,7 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
   if (stage == NULL || CLUTTER_ACTOR_IN_DESTRUCTION (stage))
     return;
 
-  was_fullscreen = _clutter_stage_is_fullscreen (stage);
+  was_fullscreen = ((stage_x11->state & CLUTTER_STAGE_STATE_FULLSCREEN) != 0);
   is_fullscreen = !!is_fullscreen;
 
   if (was_fullscreen == is_fullscreen)
@@ -485,8 +579,6 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
                                         TRUE);
             }
         }
-      else
-        stage_x11->fullscreen_on_realize = TRUE;
     }
   else
     {
@@ -518,8 +610,6 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
                                                  stage_x11->xwin_height);
             }
         }
-      else
-        stage_x11->fullscreen_on_realize = FALSE;
     }
 
   /* XXX: Note we rely on the ConfigureNotify mechanism as the common
@@ -528,139 +618,6 @@ clutter_stage_x11_set_fullscreen (ClutterStageWindow *stage_window,
    * queue a relayout etc. */
 }
 
-void
-_clutter_stage_x11_events_device_changed (ClutterStageX11 *stage_x11,
-                                          ClutterInputDevice *device,
-                                          ClutterDeviceManager *device_manager)
-{
-  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_x11);
-
-  if (clutter_input_device_get_device_mode (device) == CLUTTER_INPUT_MODE_FLOATING)
-    _clutter_device_manager_select_stage_events (device_manager,
-                                                 stage_cogl->wrapper);
-}
-
-static void
-stage_events_device_added (ClutterDeviceManager *device_manager,
-                           ClutterInputDevice *device,
-                           gpointer user_data)
-{
-  ClutterStageWindow *stage_window = user_data;
-  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_window);
-
-  if (clutter_input_device_get_device_mode (device) == CLUTTER_INPUT_MODE_FLOATING)
-    _clutter_device_manager_select_stage_events (device_manager,
-                                                 stage_cogl->wrapper);
-}
-
-static gboolean
-clutter_stage_x11_realize (ClutterStageWindow *stage_window)
-{
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
-  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_window);
-  ClutterBackend *backend = CLUTTER_BACKEND (stage_cogl->backend);
-  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend);
-  ClutterDeviceManager *device_manager;
-  gfloat width, height;
-
-  clutter_actor_get_size (CLUTTER_ACTOR (stage_cogl->wrapper), &width, &height);
-
-  CLUTTER_NOTE (BACKEND, "Wrapper size: %.2f x %.2f", width, height);
-
-  width = width * (float) stage_x11->scale_factor;
-  height = height * (float) stage_x11->scale_factor;
-
-  CLUTTER_NOTE (BACKEND, "Creating a new Cogl onscreen surface: %.2f x %.2f (factor: %d)",
-                width, height,
-                stage_x11->scale_factor);
-
-  stage_cogl->onscreen = cogl_onscreen_new (backend->cogl_context, width, height);
-
-  /* We just created a window of the size of the actor. No need to fix
-     the size of the stage, just update it. */
-  stage_x11->xwin_width = width;
-  stage_x11->xwin_height = height;
-
-  if (stage_x11->xwin != None)
-    {
-      cogl_x11_onscreen_set_foreign_window_xid (stage_cogl->onscreen,
-                                                stage_x11->xwin,
-                                                _clutter_stage_x11_update_foreign_event_mask,
-                                                stage_x11);
-
-    }
-
-  /* Chain to the parent class now. ClutterStageCogl will call cogl_framebuffer_allocate,
-     which will create the X Window we need */
-
-  if (!(clutter_stage_window_parent_iface->realize (stage_window)))
-    return FALSE;
-
-  if (stage_x11->xwin == None)
-    stage_x11->xwin = cogl_x11_onscreen_get_window_xid (stage_cogl->onscreen);
-
-  if (clutter_stages_by_xid == NULL)
-    clutter_stages_by_xid = g_hash_table_new (NULL, NULL);
-
-  g_hash_table_insert (clutter_stages_by_xid,
-                       GINT_TO_POINTER (stage_x11->xwin),
-                       stage_x11);
-
-  set_wm_pid (stage_x11);
-  set_wm_title (stage_x11);
-  set_cursor_visible (stage_x11);
-
-  /* we unconditionally select input events even with event retrieval
-   * disabled because we need to guarantee that the Clutter internal
-   * state is maintained when calling clutter_x11_handle_event() without
-   * requiring applications or embedding toolkits to select events
-   * themselves. if we did that, we'd have to document the events to be
-   * selected, and also update applications and embedding toolkits each
-   * time we added a new mask, or a new class of events.
-   *
-   * see: http://bugzilla.clutter-project.org/show_bug.cgi?id=998
-   * for the rationale of why we did conditional selection. it is now
-   * clear that a compositor should clear out the input region, since
-   * it cannot assume a perfectly clean slate coming from us.
-   *
-   * see: http://bugzilla.clutter-project.org/show_bug.cgi?id=2228
-   * for an example of things that break if we do conditional event
-   * selection.
-   */
-  XSelectInput (backend_x11->xdpy, stage_x11->xwin, CLUTTER_STAGE_X11_EVENT_MASK);
-
-  /* input events also depent on the actual device, so we need to
-   * use the device manager to let every device select them, using
-   * the event mask we passed to XSelectInput as the template
-   */
-  device_manager = clutter_device_manager_get_default ();
-  if (G_UNLIKELY (device_manager != NULL))
-    {
-      _clutter_device_manager_select_stage_events (device_manager,
-                                                   stage_cogl->wrapper);
-
-      g_signal_connect (device_manager, "device-added",
-                        G_CALLBACK (stage_events_device_added),
-                        stage_window);
-    }
-
-  clutter_stage_x11_fix_window_size (stage_x11,
-                                     stage_x11->xwin_width,
-                                     stage_x11->xwin_height);
-  clutter_stage_x11_set_wm_protocols (stage_x11);
-
-  if (stage_x11->fullscreen_on_realize)
-    {
-      stage_x11->fullscreen_on_realize = FALSE;
-
-      clutter_stage_x11_set_fullscreen (stage_window, TRUE);
-    }
-
-  CLUTTER_NOTE (BACKEND, "Successfully realized stage");
-
-  return TRUE;
-}
-
 static void
 clutter_stage_x11_set_cursor_visible (ClutterStageWindow *stage_window,
                                       gboolean            cursor_visible)
@@ -724,9 +681,9 @@ clutter_stage_x11_set_accept_focus (ClutterStageWindow *stage_window,
 }
 
 static void
-set_stage_x11_state (ClutterStageX11      *stage_x11,
-                     ClutterStageX11State  unset_flags,
-                     ClutterStageX11State  set_flags)
+set_stage_state (ClutterStageX11      *stage_x11,
+                 ClutterStageX11State  unset_flags,
+                 ClutterStageX11State  set_flags)
 {
   ClutterStageX11State new_stage_state, old_stage_state;
 
@@ -764,7 +721,7 @@ clutter_stage_x11_show (ClutterStageWindow *stage_window,
           CLUTTER_NOTE (BACKEND, "Mapping stage[%lu]",
                         (unsigned long) stage_x11->xwin);
 
-          set_stage_x11_state (stage_x11, STAGE_X11_WITHDRAWN, 0);
+          set_stage_state (stage_x11, STAGE_X11_WITHDRAWN, 0);
 
           update_wm_hints (stage_x11);
 
@@ -793,7 +750,7 @@ clutter_stage_x11_hide (ClutterStageWindow *stage_window)
   if (stage_x11->xwin != None)
     {
       if (STAGE_X11_IS_MAPPED (stage_x11))
-        set_stage_x11_state (stage_x11, 0, STAGE_X11_WITHDRAWN);
+        set_stage_state (stage_x11, 0, STAGE_X11_WITHDRAWN);
 
       g_assert (!STAGE_X11_IS_MAPPED (stage_x11));
 
@@ -816,26 +773,6 @@ clutter_stage_x11_can_clip_redraws (ClutterStageWindow *stage_window)
   return stage_x11->clipped_redraws_cool_off == 0;
 }
 
-static void
-clutter_stage_x11_set_scale_factor (ClutterStageWindow *stage_window,
-                                    int                 factor)
-{
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
-
-  if (stage_x11->fixed_scale_factor)
-    return;
-
-  stage_x11->scale_factor = factor;
-}
-
-static int
-clutter_stage_x11_get_scale_factor (ClutterStageWindow *stage_window)
-{
-  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (stage_window);
-
-  return stage_x11->scale_factor;
-}
-
 static void
 clutter_stage_x11_finalize (GObject *gobject)
 {
@@ -869,8 +806,6 @@ clutter_stage_x11_class_init (ClutterStageX11Class *klass)
 static void
 clutter_stage_x11_init (ClutterStageX11 *stage)
 {
-  const char *scale_str;
-
   stage->xwin = None;
   stage->xwin_width = 640;
   stage->xwin_height = 480;
@@ -883,20 +818,6 @@ clutter_stage_x11_init (ClutterStageX11 *stage)
   stage->accept_focus = TRUE;
 
   stage->title = NULL;
-
-  scale_str = g_getenv ("CLUTTER_SCALE");
-  if (scale_str != NULL)
-    {
-      CLUTTER_NOTE (BACKEND, "Scale factor set using environment variable: %d ('%s')",
-                    atol (scale_str),
-                    scale_str);
-      stage->fixed_scale_factor = TRUE;
-      stage->scale_factor = atol (scale_str);
-      stage->xwin_width *= stage->scale_factor;
-      stage->xwin_height *= stage->scale_factor;
-    }
-  else
-    stage->scale_factor = 1;
 }
 
 static void
@@ -916,8 +837,6 @@ clutter_stage_window_iface_init (ClutterStageWindowIface *iface)
   iface->realize = clutter_stage_x11_realize;
   iface->unrealize = clutter_stage_x11_unrealize;
   iface->can_clip_redraws = clutter_stage_x11_can_clip_redraws;
-  iface->set_scale_factor = clutter_stage_x11_set_scale_factor;
-  iface->get_scale_factor = clutter_stage_x11_get_scale_factor;
 }
 
 static inline void
@@ -941,14 +860,12 @@ handle_wm_protocols_event (ClutterBackendX11 *backend_x11,
                            ClutterStageX11   *stage_x11,
                            XEvent            *xevent)
 {
+  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_x11);
   Atom atom = (Atom) xevent->xclient.data.l[0];
 
   if (atom == backend_x11->atom_WM_DELETE_WINDOW &&
       xevent->xany.window == stage_x11->xwin)
     {
-#ifdef CLUTTER_ENABLE_DEBUG
-      ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (stage_x11);
-
       /* the WM_DELETE_WINDOW is a request: we do not destroy
        * the window right away, as it might contain vital data;
        * we relay the event to the application and we let it
@@ -958,7 +875,6 @@ handle_wm_protocols_event (ClutterBackendX11 *backend_x11,
                     _clutter_actor_get_debug_name (CLUTTER_ACTOR (stage_cogl->wrapper)),
                     stage_cogl->wrapper,
                     (unsigned int) stage_x11->xwin);
-#endif /* CLUTTER_ENABLE_DEBUG */
 
       set_user_time (backend_x11, stage_x11, xevent->xclient.data.l[1]);
 
@@ -988,7 +904,7 @@ clipped_redraws_cool_off_cb (void *data)
 
   stage_x11->clipped_redraws_cool_off = 0;
 
-  return G_SOURCE_REMOVE;
+  return FALSE;
 }
 
 static ClutterTranslateReturn
@@ -996,23 +912,18 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
                                    gpointer                native,
                                    ClutterEvent           *event)
 {
-  ClutterStageX11 *stage_x11;
-  ClutterStageCogl *stage_cogl;
+  ClutterStageX11 *stage_x11 = CLUTTER_STAGE_X11 (translator);
+  ClutterStageCogl *stage_cogl = CLUTTER_STAGE_COGL (translator);
   ClutterTranslateReturn res = CLUTTER_TRANSLATE_CONTINUE;
-  ClutterBackendX11 *backend_x11;
-  Window stage_xwindow;
+  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (stage_cogl->backend);
+  Window stage_xwindow = stage_x11->xwin;
   XEvent *xevent = native;
   ClutterStage *stage;
 
-  stage_cogl = clutter_x11_get_stage_window_from_window (xevent->xany.window);
-  if (stage_cogl == NULL)
+  stage = clutter_x11_get_stage_from_window (xevent->xany.window);
+  if (stage == NULL)
     return CLUTTER_TRANSLATE_CONTINUE;
 
-  stage = stage_cogl->wrapper;
-  stage_x11 = CLUTTER_STAGE_X11 (stage_cogl);
-  backend_x11 = CLUTTER_BACKEND_X11 (stage_cogl->backend);
-  stage_xwindow = stage_x11->xwin;
-
   switch (xevent->type)
     {
     case ConfigureNotify:
@@ -1028,7 +939,7 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
           /* When fullscreen, we'll keep the xwin_width/height
              variables to track the old size of the window and we'll
              assume all ConfigureNotifies constitute a size change */
-          if (_clutter_stage_is_fullscreen (stage))
+          if ((stage_x11->state & CLUTTER_STAGE_STATE_FULLSCREEN))
             size_changed = TRUE;
           else if ((stage_x11->xwin_width != xevent->xconfigure.width) ||
                    (stage_x11->xwin_height != xevent->xconfigure.height))
@@ -1039,8 +950,8 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
             }
 
           clutter_actor_set_size (CLUTTER_ACTOR (stage),
-                                  xevent->xconfigure.width / stage_x11->scale_factor,
-                                  xevent->xconfigure.height / stage_x11->scale_factor);
+                                  xevent->xconfigure.width,
+                                  xevent->xconfigure.height);
 
           CLUTTER_UNSET_PRIVATE_FLAGS (stage_cogl->wrapper, CLUTTER_IN_RESIZE);
 
@@ -1082,9 +993,8 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
                 g_source_remove (stage_x11->clipped_redraws_cool_off);
 
               stage_x11->clipped_redraws_cool_off =
-                clutter_threads_add_timeout (1000,
-                                             clipped_redraws_cool_off_cb,
-                                             stage_x11);
+                g_timeout_add_seconds (1, clipped_redraws_cool_off_cb,
+                                       stage_x11);
 
               /* Queue a relayout - we want glViewport to be called
                * with the correct values, and this is done in ClutterStage
@@ -1129,9 +1039,9 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
 
           if (type != None && data != NULL)
             {
-              gboolean is_fullscreen = FALSE;
               Atom *atoms = (Atom *) data;
               gulong i;
+              gboolean is_fullscreen = FALSE;
 
               for (i = 0; i < n_items; i++)
                 {
@@ -1139,18 +1049,26 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
                     fullscreen_set = TRUE;
                 }
 
-              is_fullscreen = _clutter_stage_is_fullscreen (stage_cogl->wrapper);
+              is_fullscreen =
+                (stage_x11->state & CLUTTER_STAGE_STATE_FULLSCREEN);
 
               if (fullscreen_set != is_fullscreen)
                 {
                   if (fullscreen_set)
-                    _clutter_stage_update_state (stage_cogl->wrapper,
-                                                 0,
-                                                 CLUTTER_STAGE_STATE_FULLSCREEN);
+                    stage_x11->state |= CLUTTER_STAGE_STATE_FULLSCREEN;
                   else
-                    _clutter_stage_update_state (stage_cogl->wrapper,
-                                                 CLUTTER_STAGE_STATE_FULLSCREEN,
-                                                 0);
+                    stage_x11->state &= ~CLUTTER_STAGE_STATE_FULLSCREEN;
+
+                  stage_x11->fullscreening = fullscreen_set;
+
+                  event->any.type = CLUTTER_STAGE_STATE;
+                  event->any.source = CLUTTER_ACTOR (stage);
+                  event->any.stage = stage;
+                  event->stage_state.changed_mask =
+                    CLUTTER_STAGE_STATE_FULLSCREEN;
+                  event->stage_state.new_state = stage_x11->state;
+
+                  res = CLUTTER_TRANSLATE_QUEUE;
                 }
 
               XFree (data);
@@ -1159,27 +1077,42 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
       break;
 
     case FocusIn:
-      if (!_clutter_stage_is_activated (stage_cogl->wrapper))
+      if (!(stage_x11->state & CLUTTER_STAGE_STATE_ACTIVATED))
         {
-          _clutter_stage_update_state (stage_cogl->wrapper,
-                                       0,
-                                       CLUTTER_STAGE_STATE_ACTIVATED);
+          /* TODO: check the detail? */
+          stage_x11->state |= CLUTTER_STAGE_STATE_ACTIVATED;
+
+          event->type = CLUTTER_STAGE_STATE;
+          event->any.source = CLUTTER_ACTOR (stage);
+          event->any.stage = stage;
+          event->stage_state.changed_mask = CLUTTER_STAGE_STATE_ACTIVATED;
+          event->stage_state.new_state = stage_x11->state;
+
+          res = CLUTTER_TRANSLATE_QUEUE;
         }
       break;
 
     case FocusOut:
-      if (_clutter_stage_is_activated (stage_cogl->wrapper))
+      if (stage_x11->state & CLUTTER_STAGE_STATE_ACTIVATED)
         {
-          _clutter_stage_update_state (stage_cogl->wrapper,
-                                       CLUTTER_STAGE_STATE_ACTIVATED,
-                                       0);
+          /* TODO: check the detail? */
+          stage_x11->state &= ~CLUTTER_STAGE_STATE_ACTIVATED;
+
+          event->any.type = CLUTTER_STAGE_STATE;
+          event->any.source = CLUTTER_ACTOR (stage);
+          event->any.stage = stage;
+          event->stage_state.changed_mask = CLUTTER_STAGE_STATE_ACTIVATED;
+          event->stage_state.new_state = stage_x11->state;
+
+          res = CLUTTER_TRANSLATE_QUEUE;
         }
       break;
 
     case Expose:
       {
         XExposeEvent *expose = (XExposeEvent *) xevent;
-        cairo_rectangle_int_t clip;
+        ClutterPaintVolume clip;
+        ClutterVertex origin;
 
         CLUTTER_NOTE (EVENT,
                       "expose for stage: %s[%p], win:0x%x - "
@@ -1192,11 +1125,19 @@ clutter_stage_x11_translate_event (ClutterEventTranslator *translator,
                       expose->width,
                       expose->height);
 
-        clip.x = expose->x / stage_x11->scale_factor;
-        clip.y = expose->y / stage_x11->scale_factor;
-        clip.width = expose->width / stage_x11->scale_factor;
-        clip.height = expose->height / stage_x11->scale_factor;
-        clutter_actor_queue_redraw_with_clip (CLUTTER_ACTOR (stage), &clip);
+        origin.x = expose->x;
+        origin.y = expose->y;
+        origin.z = 0;
+
+        _clutter_paint_volume_init_static (&clip, CLUTTER_ACTOR (stage));
+
+        clutter_paint_volume_set_origin (&clip, &origin);
+        clutter_paint_volume_set_width (&clip, expose->width);
+        clutter_paint_volume_set_height (&clip, expose->height);
+
+        _clutter_actor_queue_redraw_with_clip (CLUTTER_ACTOR (stage), 0, &clip);
+
+        clutter_paint_volume_free (&clip);
       }
       break;
 
@@ -1268,21 +1209,11 @@ clutter_x11_get_stage_window (ClutterStage *stage)
   return CLUTTER_STAGE_X11 (impl)->xwin;
 }
 
-static ClutterStageCogl *
-clutter_x11_get_stage_window_from_window (Window win)
-{
-  if (clutter_stages_by_xid == NULL)
-    return NULL;
-
-  return g_hash_table_lookup (clutter_stages_by_xid,
-                              GINT_TO_POINTER (win));
-}
-
 /**
  * clutter_x11_get_stage_from_window:
  * @win: an X Window ID
  *
- * Gets the stage for a particular X window.
+ * Gets the stage for a particular X window.  
  *
  * Return value: (transfer none): A #ClutterStage, or% NULL if a stage
  *   does not exist for the window
@@ -1294,7 +1225,11 @@ clutter_x11_get_stage_from_window (Window win)
 {
   ClutterStageCogl *stage_cogl;
 
-  stage_cogl = clutter_x11_get_stage_window_from_window (win);
+  if (clutter_stages_by_xid == NULL)
+    return NULL;
+
+  stage_cogl = g_hash_table_lookup (clutter_stages_by_xid,
+				    GINT_TO_POINTER (win));
 
   if (stage_cogl != NULL)
     return stage_cogl->wrapper;
@@ -1361,8 +1296,8 @@ set_foreign_window_callback (ClutterActor *actor,
   fwd->stage_x11->xwin = fwd->xwindow;
   fwd->stage_x11->is_foreign_xwin = TRUE;
 
-  fwd->stage_x11->xwin_width = fwd->geom.width * fwd->stage_x11->scale_factor;
-  fwd->stage_x11->xwin_height = fwd->geom.height * fwd->stage_x11->scale_factor;
+  fwd->stage_x11->xwin_width = fwd->geom.width;
+  fwd->stage_x11->xwin_height = fwd->geom.height;
 
   clutter_actor_set_size (actor, fwd->geom.width, fwd->geom.height);
 
@@ -1462,8 +1397,8 @@ clutter_x11_set_stage_foreign (ClutterStage *stage,
 
   fwd.geom.x = x;
   fwd.geom.y = y;
-  fwd.geom.width = width / stage_x11->scale_factor;
-  fwd.geom.height = height / stage_x11->scale_factor;
+  fwd.geom.width = width;
+  fwd.geom.height = height;
 
   actor = CLUTTER_ACTOR (stage);
 
