@@ -134,6 +134,7 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/actor", actor_fixed_size);
   TEST_CONFORM_SIMPLE ("/actor", actor_preferred_size);
   TEST_CONFORM_SIMPLE ("/actor", test_offscreen_redirect);
+  TEST_CONFORM_SIMPLE ("/actor", test_shader_effect);
 
   TEST_CONFORM_SIMPLE ("/invariants", test_initial_state);
   TEST_CONFORM_SIMPLE ("/invariants", test_shown_not_parented);
@@ -144,6 +145,7 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/invariants", test_show_on_set_parent);
   TEST_CONFORM_SIMPLE ("/invariants", test_clone_no_map);
   TEST_CONFORM_SIMPLE ("/invariants", test_contains);
+  TEST_CONFORM_SIMPLE ("/invariants", default_stage);
 
   TEST_CONFORM_SIMPLE ("/opacity", test_label_opacity);
   TEST_CONFORM_SIMPLE ("/opacity", test_rectangle_opacity);
@@ -181,7 +183,8 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/model", test_list_model_from_script);
   TEST_CONFORM_SIMPLE ("/model", test_list_model_row_changed);
 
-  TEST_CONFORM_SIMPLE ("/color", test_color_from_string);
+  TEST_CONFORM_SIMPLE ("/color", test_color_from_string_valid);
+  TEST_CONFORM_SIMPLE ("/color", test_color_from_string_invalid);
   TEST_CONFORM_SIMPLE ("/color", test_color_to_string);
   TEST_CONFORM_SIMPLE ("/color", test_color_hls_roundtrip);
   TEST_CONFORM_SIMPLE ("/color", test_color_operators);
